### input packages
library(dplyr)
library(stringr)
library(data.table)
library(rlist)
library(ggplot2)
### input parameters
metaXY_folder='E:\\metabolic\\raw\\msv000084112\\meta\\test'
metaX='D:\\metabolic\\metaX-feature.txt'
FDR_par=0.01
sig_loc='D:\\metabolic\\output\\data\\metaX-quant.txt'
sig_method='VIP'
xrda_loc="D:/metabolic/x.rda"

### load quan(after treatment by metaX)&qual files
### merge XYmeta files(in one folder)
metaX_feature=fread(metaX,stringsAsFactors = F,data.table = F)
load(xrda_loc)
colnames(x)[1]='name'
metaX_anno=metaX_feature[,c(1,5:13,26:28)]
metaX_feature=merge(metaX_anno,x,all=F,by=c('name'))
metaXY_file=list.files(metaXY_folder,full.names = T)
metaXY=vector()
for(i in 1:length(metaXY_file)){
  met=fread(metaXY_file[i],stringsAsFactors = F,data.table = F,sep = '\t')
  met=cbind(rep(i,each=nrow(met)),met)
  metaXY=qpcR:::rbind.na(metaXY,met)
}
metaXY=metaXY[-1, ]
colnames(metaXY)[1]='sample_number'
metaXY=filter(metaXY,FDR<=FDR_par)
metaXY=cbind(1:nrow(metaXY),metaXY)
colnames(metaXY)[1]='index'


### metabolites references treatment(Depending on the reference library)
meta_list=metaXY$Reference_spectrum
meta_list=substr(meta_list,19,nchar(meta_list))
metaXY$Reference_spectrum=meta_list

### quantified metabolites by metaX_feature
ID=vector(mode = 'character',length = nrow(metaX_feature))
anno_index=vector(mode='character',length = nrow(metaX_feature))
for(i in 1:nrow(metaX_feature)){
  med1=filter(metaXY,Query_precursor_mass<=metaX_feature$mzmax[i]&Query_precursor_mass>=metaX_feature$mzmin[i])
  med1=filter(med1,Query_precursor_retention_time<=metaX_feature$rtmax[i]&Query_precursor_retention_time>=metaX_feature$rtmin[i])
  if(nrow(med1)!=0){
    index=med1$index
    name=med1$Reference_spectrum
    name_index=as.data.frame(cbind(name,index),stringsAsFactors=F)
    name_fre=as.data.frame(table(name),stringsAsFactors=F)
    name_fre=name_fre[which(name_fre$Freq==max(name_fre$Freq)),]
    if(nrow(name_fre)==1){
      ID[i]=name_fre$name[1]
      anno_index[i]=paste(name_index$index[which(name_index$name==name_fre$name[1])],collapse = ';')
    }
  }
}
metaX_feature=cbind(ID,anno_index,metaX_feature)
metaX_feature=metaX_feature[-which(metaX_feature$ID==''),]

### input significant analysis result
sig_meta=fread(sig_loc,stringsAsFactors = F,data.table = F)
colnames(sig_meta)[1]='name'
metaX_feature=merge(sig_meta,metaX_feature,all=F,by='name')

### output files
write.table(metaXY,file = 'FDR_metaXY.tsv',sep = '\t',row.names = F)
write.table(metaX_feature,file = 'FDR_quan.tsv',sep = '\t',row.names = F)

### draw the dot_plot by mz and rt
sig_index=which(metaX_feature[,sig_method]<=0.05)
sig_vector=vector(mode = 'character',length=nrow(metaX_feature))
sig_vector[sig_index]='sig'
sig_vector[-sig_index]='nonsig'

### draw the dot_plot by mz and rt
p=ggplot(metaX_feature,aes(x=rtmed,y=mzmed))+
  geom_point(aes(colour=sig_vector))+
  theme_bw()+scale_color_manual(values=c('turquoise','red'))
p
